@@ -1,11 +1,12 @@
-import time
-import requests
-from urllib import parse as parseurl
-from command_tool.utils.utils import error_exit, set_config, logger
-import json
 import hashlib
-from command_tool.utils.user import show_user
+import json
 import re
+import time
+from urllib import parse as parseurl
+
+import requests
+from command_tool.utils.user import show_user
+from command_tool.utils.utils import error_exit, logger, set_config
 
 
 def registration(username, email, password, baseurl):
@@ -34,7 +35,7 @@ def registration(username, email, password, baseurl):
     return error_exit(json.loads(r.text))
 
 
-def login(email, password, oauth_token, baseurl, username=''):
+def login(email, password, oauth_token, baseurl, username=""):
     """
     login into Scantist backend and get an apikey to access other APIs
     :param username:
@@ -49,7 +50,7 @@ def login(email, password, oauth_token, baseurl, username=''):
 
     if (not email and not username) or not password:
         error_exit("Please provide email and password.")
-        
+
     if oauth_token:
         return _login_with_github(oauth_token, baseurl)
 
@@ -91,9 +92,7 @@ def create_scantist_token(apikey, baseurl, org_id):
         "Content-type": "application/json",
         "Authorization": "Token " + apikey,
     }
-    payload = {
-        "name": "SCANTISTTOKEN%s" % int(time.time())
-    }
+    payload = {"name": "SCANTISTTOKEN%s" % int(time.time())}
     r = requests.post(url=url, json=payload, headers=headers)
     if r.status_code != 201:
         error_exit("failed to create org token,err=%s" % r.text)
@@ -120,4 +119,4 @@ def _login_with_github(personal_access_token, baseurl):
         error_exit("failed to get api key from Github")
 
     set_config("SCANTIST", "api_key", apikey)
-    return {"apikey": apikey}
\ No newline at end of file
+    return {"apikey": apikey}
